#!/usr/bin/perl

use utf8;
use warnings;

binmode STDIN,  ":utf8";
binmode STDOUT, ":utf8";

my %cform;

open(F, "cforms.txt") || die;
while (<F>) {
  chomp;
  next if (/^\s*$/);
  utf8::decode($_);
  my ($f, $t, $suffix) = split /\s+/, $_;
  $suffix = "" if ($suffix eq "*");
  push @{$cform{$f}{$t}},  $suffix;
}
close(F);

sub Output($$) {
  my ($w, $f) = @_;
  return if ($w eq "");
  my @csv = split /,/, $f;
  if (defined $cform{$csv[1]}) {
    my $ctype = $csv[2];
    my $suffix= ${$cform{$csv[1]}{$ctype}}[0];
    die "$f is not defined\n" if (!defined $suffix);
    my $word_prefix = substr($w, 0, length($w) - length($suffix));
    my $read_prefix = substr($csv[4], 0, length($csv[4]) - length($suffix));
    my $base_suffix = ${$cform{$csv[1]}{"基本形"}}[0];
    die "$f is not defined as base\n" if (!defined $base_suffix);
    for my $c (sort keys %{$cform{$csv[1]}}) {
      my @sufs = @{$cform{$csv[1]}{$c}};
      for my $suf (@sufs) {
        my $surface = $word_prefix . $suf;
        next if ($surface eq "");	  	    
        printf("%s,0,0,0,%s,%s,%s,%s,%s,%s\n",
               $surface,
               $csv[0],
               $csv[1],
               $c,
               $word_prefix . $suf,
               $read_prefix . $suf,
               $csv[5]);
      }
    }
  } else {
    print "$w,0,0,0,$f\n";
  }
}

while (<>) {
  chomp;
  utf8::decode($_);
  next if (/^EOS/);
  my ($w, $f) = split /\t/, $_;
  my @c = split /,/,  $f;
  next if (@c != 6);
  if ($c[4] =~ /\p{InHiragana}/) {
    Output($w, $f);
  } elsif ($w =~ /^[0-9０-９]+$/ && $c[0] eq "名詞") {
    next;
  } elsif (($c[0] eq "特殊" && length($w) <= 1)) {
    Output($w, $f);
  } elsif ($c[0] eq "接尾辞" || $c[1] eq "空白") {
    Output($w, $f);	
  }
}
