#!/usr/bin/perl -w
use warnings;
use strict;
use CGI;
use LWP::UserAgent;
use Getopt::Std;
my %opt;
getopt('n:s:' => \%opt);

my $appid = "";

my $url = "http://api.jlp.yahoo.co.jp/MAService/V1/parse";
my $request_base = "response=surface,feature&appid=$appid&sentence=";
my $max_request = $opt{n} || 5000;
my $max_sentence = $opt{s} || 5000;
my $max_byte = 95000;  # 100k limit per request

sub Output($$) {
  my ($ua, $sentence) = @_;
  my $req = new HTTP::Request POST => $url;
  $req->content_type('application/x-www-form-urlencoded');
  $req->content($request_base . $sentence);
  my $res = $ua->request($req);
  my $result = $res->content if ($res->is_success);
  my $emit = 0;
  while ($result =~ s/<word><surface>([^<]+)<\/surface><feature>([^<]+)<\/feature><\/word>//) {
    $emit = 1;
    my $word = $1;
    my $feature = $2;
    print "$word\t$feature\n" if ($word !~ /\t/);
    if ($word eq "。") {
      print "EOS\n" if ($emit);
      $emit = 0;
    }
  }
  print "EOS\n" if ($emit);
}

my $ua = new LWP::UserAgent;
$ua->agent("");
my $sentence = "";
my $num_request = 0;
my $num_sentence = 0;

while (my $line = <>) {
  chomp $line;
  if ($line !~ /。$/) {
    $line .= "。";
  }
  $line = CGI::escape($line);
  if (length($sentence) >= $max_byte) {
    Output($ua, $sentence);
    exit if (++$num_request > $max_request);
    exit if (++$num_sentence > $max_sentence);      
    print STDERR "num_request: $num_request\tnum_sentence: $num_sentence\n";
    $sentence = "";
  } else {
    ++$num_sentence;
    $sentence .= $line;
  }
}
Output($ua, $sentence);
